JIC Bio Image
=============

.. image:: https://badge.fury.io/py/jicbioimage.svg
   :target: http://badge.fury.io/py/jicbioimage
   :alt: PyPi package

The ``jicbioimage`` Python package makes it easy to explore microscopy
data in a programmatic fashion. Exploring images via coding means that the
exploratory work becomes recorded and reproducible.  Furthermore, it makes it
easier to convert the exploratory work into (semi) automated analysis work
flows.

- GitHub: https://github.com/JIC-CSB/jicbioimage
- PyPI: https://pypi.python.org/pypi/jicbioimage
- Free software: MIT License
